@@ -1,10 +1,11 @@
 
 library(SoPhy, lib=if (file.exists("~/TMP/SoPhy")) "~/TMP")
 
-s <- "/home/schlather/article/R/NEW.RF/RandomFields/tests/source.R"
-if (file.exists(s)) source(s)
+s <- "/home/schlather/R/RF/RandomFields/tests/source.R"
+if (EXTENDED.TESTING <- file.exists(s)) source(s)
+# EXTENDED.TESTING <- FALSE
 
-.path <- "/home/schlather/article/R/SOPHY/SoPhy/R/"
+.path <- "/home/schlather/R/SOPHY/SoPhy/R/"
 if (file.exists(paste(.path, "swms2d.R", sep=""))) {
   Source <- function(x) {
     cat(x, "...\n")
@@ -16,6 +17,7 @@ if (file.exists(paste(.path, "swms2d.R", sep=""))) {
   Source("analytic.R")
   Source("extremal.coeff.R")
   Source("rgb.R")
+  Source("sh.R")
   Source("simu.R")
   Source("swms2d.R")
 }
